scdatatools package
===================

.. automodule:: scdatatools
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   scdatatools.cli
   scdatatools.cryxml
   scdatatools.forge

Submodules
----------

.. toctree::
   :maxdepth: 4

   scdatatools.p4k
   scdatatools.utils
